@@ -12,6 +12,9 @@ from chaste_codegen.model_with_conversions import (
 )
 
 
+TIME_STAMP = time.strftime('%Y-%m-%d %H:%M:%S')
+
+
 class ChasteModel(object):
     """ Holds information about a cellml model for which chaste code is to be generated.
 
@@ -92,7 +95,7 @@ class ChasteModel(object):
              'header_ext': kwargs.get('header_ext', '.hpp'),
              'dynamically_loadable': kwargs.get('dynamically_loadable', False),
              'modifiers': self._format_modifiers(),
-             'generation_date': time.strftime('%Y-%m-%d %H:%M:%S'),
+             'generation_date': TIME_STAMP,
              'use_get_intracellular_calcium_concentration':
                  self._model.cytosolic_calcium_concentration_var in self._model.state_vars,
              'membrane_voltage_index': MEMBRANE_VOLTAGE_INDEX,
@@ -182,7 +185,7 @@ class ChasteModel(object):
         """ Get the defining equations for derived quantities"""
         return get_equations_for(self._model, self._derived_quant)
 
-    def _add_printers(self):
+    def _add_printers(self, lookup_table_function=lambda e: None):
         """ Initialises Printers for outputting chaste code. """
         def get_variable_name(s, interface=False):
             """Get the correct variable name based on the variable and whether it should be in the chaste_interface."""
@@ -203,7 +206,8 @@ class ChasteModel(object):
                              else self._print_modifiable_parameters(variable),
                              lambda deriv: 'd_dt_chaste_interface_' +
                                            (get_variable_name(deriv.expr)
-                                            if isinstance(deriv, Derivative) else get_variable_name(deriv)))
+                                            if isinstance(deriv, Derivative) else get_variable_name(deriv)),
+                             lookup_table_function)
 
         # Printer for printing variable in comments e.g. for ode system information
         self._name_printer = cg.ChastePrinter(lambda variable: get_variable_name(variable))
@@ -219,7 +223,8 @@ class ChasteModel(object):
                              self._printer.doprint(self._model.time_variable) + ')'
                              if variable in self._modifiers and variable not in modifiers_with_defining_eqs
                              else self._printer.doprint(variable),
-                             lambda deriv: self._printer.doprint(deriv))
+                             lambda deriv: self._printer.doprint(deriv),
+                             self._printer.lookup_table_function)
         if modifier in self._modifiers:
             return self._format_modifier(modifier) + '->Calc(' + modifier_printer.doprint(eq) + ', ' + \
                 self._printer.doprint(self._model.time_variable) + ')'
@@ -320,7 +325,7 @@ class ChasteModel(object):
 
         use_verify_state_variables = next(filter(lambda eq: eq['range_low'] != '' or eq['range_high'] != '',
                                                  formatted_state_vars), None) is not None
-        return formatted_state_vars, use_verify_state_variables
+        return (formatted_state_vars, use_verify_state_variables)
 
     def _format_default_stimulus(self):
         """ Format eqs for stimulus_current for outputting to chaste code"""
@@ -353,17 +358,23 @@ class ChasteModel(object):
         # as those are handled by _print_rhs_with_modifiers
         modifiers_with_defining_eqs = set((eq.lhs for eq in derivative_equations)) | self._model.state_vars
         # exclude ionic currents
-        formatted_deriv_eqs = [{'lhs': self._printer.doprint(eq.lhs),
-                                'rhs': self._print_rhs_with_modifiers(eq.lhs, eq.rhs, modifiers_with_defining_eqs),
-                                'sympy_lhs': eq.lhs,
-                                'units': self._model.units.format(self._model.units.evaluate_units(eq.lhs)),
-                                'in_eqs_excl_voltage': eq in self._derivative_eqs_excl_voltage,
-                                'in_membrane_voltage': eq in self._derivative_eqs_voltage,
-                                'is_voltage': isinstance(eq.lhs, Derivative) and
-                                eq.lhs.args[0] == self._model.membrane_voltage_var}
+        formatted_deriv_eqs = [self.format_derivative_equation(eq, modifiers_with_defining_eqs)
                                for eq in derivative_equations]
         return formatted_deriv_eqs
 
+    def format_derivative_equation(self, eq, modifiers_with_defining_eqs):
+        """ Format an individual derivative equation
+            specified so that other model types can specify more detailed printing """
+        return {'lhs': self._printer.doprint(eq.lhs),
+                'rhs': self._print_rhs_with_modifiers(eq.lhs, eq.rhs, modifiers_with_defining_eqs),
+                'sympy_lhs': eq.lhs,
+                'sympy_rhs': eq.rhs,
+                'units': self._model.units.format(self._model.units.evaluate_units(eq.lhs)),
+                'in_eqs_excl_voltage': eq in self._derivative_eqs_excl_voltage,
+                'in_membrane_voltage': eq in self._derivative_eqs_voltage,
+                'is_voltage': isinstance(eq.lhs, Derivative) and
+                eq.lhs.args[0] == self._model.membrane_voltage_var}
+
     def _format_free_variable(self):
         """ Format free variable for chaste output"""
         return {'name': self._model.get_display_name(self._model.time_variable, OXMETA),
